"""
Advent of Code 2021 - Day 07

Run with:
    python puzzles/day07.py inputs/day07.txt
"""

import pathlib
import sys
from statistics import median
from typing import List, Tuple


class AlignCrabSubs:
    positions: List[int]

    def __init__(self, positions: List[int]) -> None:
        self.positions = positions

    def calc_least_fuel(self) -> int:
        target = median(self.positions)
        fuel = 0
        for num in self.positions:
            fuel += abs(num - target)

        return int(fuel)


def part1(inputs: List[int]) -> int:
    subs = AlignCrabSubs(inputs)
    return subs.calc_least_fuel()


def part2(inputs: List[int]) -> int:
    return False


def parse(inputs: str) -> List[int]:
    """Parse the input string"""
    return [int(value) for value in inputs.split(",")]


def solve(path: str) -> Tuple[int, int]:
    """Solve the puzzle"""
    puzzle_input = parse(pathlib.Path(path).read_text().strip())
    part1_result = part1(puzzle_input)
    part2_result = part2(puzzle_input)

    return part1_result, part2_result


def main() -> None:
    for path in sys.argv[1:]:
        print(f"Input File: {path}")

        part1_result, part2_result = solve(path)

        print(f"Part 1 Result: {part1_result}")
        print(f"Part 2 Result: {part2_result}")


if __name__ == "__main__":
    main()
